@@ -1,5 +1,8 @@
 from tasq_cli import jobs
 from tasq_cli import upload
+from tasq_cli import settings
+
+VERSION = settings.VERSION
 
 def upload_csv(file_name, project_id, tag):
     """Upload a csv of images to the project.
