@@ -14,15 +14,22 @@ def run_job(project_id, tag):
     tag = tag
     headers = {'content-type': 'application/vnd.api+json', 'accept': 'application/vnd.api+json'}
 
-    data = {'data': {'type': 'jobs',
-              'attributes': {'name': '',
-                             'includeModel': False,
-                             'tags': [tag],
-                             'excludeTags': [],
-                             'maxResources': None,
-                             'forQualification': False,
-                             'projectId': project_id,
-                             'projectResourceIds': []}}}
+    data = {
+        'data': {
+            'type': 'jobs',
+            'attributes': {
+                'name': '',
+                'includeModel': False,
+                'resourcesFilter': {
+                    'tags': [tag],
+                    'excludeTags': [],
+                },
+                'maxResources': None,
+                'forQualification': False,
+                'projectId': project_id
+            }
+        }
+    }
     r = make_request(url, headers=headers, json=data)
     data = r.json()['data']
     del data['relationships']
