@@ -7,7 +7,7 @@ from tasq_cli.server import make_request
 
 logger = None
 
-def list_projects(args):
+def list_projects():
     global logger
     logger = settings.get_logger()
     url = f'/projects/?sort=-id&page[size]=100'
