@@ -260,7 +260,7 @@ def upload_csv(path, project_id, tag):
                     "id": generic_file_id
                 },
                 "dataset": {
-                    "type": "dataset",
+                    "type": "datasets",
                     "id": dataset_id
                 }
             }
